OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
    "See %s" : "Voir %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire de configuration%s.",
    "Sample configuration detected" : "Configuration d'exemple détectée",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
    "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
    "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
    "%sbit or higher PHP required." : "%sbit ou PHP supérieur est requis.",
    "Following databases are supported: %s" : "Les bases de données suivantes sont supportées : %s",
    "The command line tool %s could not be found" : "La commande %s est introuvable",
    "The library %s is not available." : "La librairie %s n'est pas disponible.",
    "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
    "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
    "Following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
    "ownCloud %s or higher is required." : "ownCloud %s ou supérieur est requis.",
    "ownCloud %s or lower is required." : "ownCloud %s ou inférieur est requis.",
    "Unknown filetype" : "Type de fichier inconnu",
    "Invalid image" : "Image non valable",
    "Avatar image is not square" : "L'image de l'avatar n'est pas carrée",
    "today" : "aujourd'hui",
    "yesterday" : "hier",
    "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
    "last month" : "le mois dernier",
    "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois"],
    "last year" : "l'année dernière",
    "_%n year ago_::_%n years ago_" : ["il y a %n an","il y a %n ans"],
    "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures"],
    "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
    "seconds ago" : "il y a quelques secondes",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'id: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
    "Builtin" : "Intégré",
    "None" : "Aucun",
    "Username and password" : "Nom d'utilisateur et mot de passe",
    "Username" : "Nom d'utilisateur",
    "Password" : "Mot de passe",
    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegardés pour la session",
    "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
    "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
    "4-byte characters are not supported in file names" : "Les caractères sur 4 octets ne sont pas pris en charge dans les noms de fichiers",
    "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
    "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
    "File name is too long" : "Nom de fichier trop long",
    "App directory already exists" : "Le dossier de l'application existe déjà",
    "Can't create app folder. Please fix permissions. %s" : "Impossible de créer le dossier de l'application. Corrigez les droits d'accès. %s",
    "Archive does not contain a directory named %s" : "Le fichier archive ne contient pas de répertoire %s",
    "No source specified when installing app" : "Aucune source spécifiée pour installer l'application",
    "No href specified when installing app from http" : "Aucun href spécifié pour installer l'application par http",
    "No path specified when installing app from local file" : "Aucun chemin spécifié pour installer l'application depuis un fichier local",
    "Archives of type %s are not supported" : "Les archives de type %s ne sont pas prises en charge",
    "Failed to open archive when installing app" : "Échec de l'ouverture de l'archive lors de l'installation de l'application",
    "App does not provide an info.xml file" : "L'application ne fournit pas de fichier info.xml",
    "App cannot be installed because appinfo file cannot be read." : "L'application ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La signature n'a pas pu être vérifiée. Merci de contacter le développeur de l'application et de vérifier votre page d'administration.",
    "App can't be installed because of not allowed code in the App" : "L'application ne peut être installée car elle contient du code non-autorisé",
    "App can't be installed because it is not compatible with this version of ownCloud" : "L'application ne peut être installée car elle n'est pas compatible avec cette version de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'application ne peut être installée car elle contient la balise <shipped>true</shipped> qui n'est pas autorisée pour les applications non incluses par défaut",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'App ne peut pas être installé car la version dans info.xml diffère de la version signalée par l' app store",
    "Apps" : "Applications",
    "General" : "Généraux",
    "Storage" : "Stockage",
    "Security" : "Sécurité",
    "Encryption" : "Chiffrement",
    "Sharing" : "Partage",
    "Search" : "Rechercher",
    "Updates" : "Mises à jour",
    "Help & Tips" : "Aide et Astuces",
    "Additional" : "Suppléments",
    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
    "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
    "%s enter the database name." : "%s entrez le nom de la base de données.",
    "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
    "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
    "DB Error: \"%s\"" : "Erreur de la base de données : \"%s\"",
    "Offending command was: \"%s\"" : "La requête en cause est : \"%s\"",
    "You need to enter either an existing account or the administrator." : "Vous devez spécifier le nom d'un compte existant, ou celui de l'administrateur.",
    "Offending command was: \"%s\", name: %s, password: %s" : "La requête en cause est : \"%s\", nom : %s, mot de passe : %s",
    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
    "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez supprimer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
    "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
    "Can't create or write into the data directory %s" : "Impossible de créer, ou d'écrire dans, le répertoire des données %s",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
    "%s shared »%s« with you" : "%s a partagé «%s» avec vous",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Le partage de %s a échoué car l’infrastructure n'autorise pas les partages de type %i",
    "Sharing %s failed, because the file does not exist" : "Le partage de %s a échoué car le fichier n'existe pas",
    "You are not allowed to share %s" : "Vous n'êtes pas autorisé à partager %s",
    "Sharing %s failed, because you can not share with yourself" : "Le partage de %s a échoué car vous ne pouvez pas partager avec vous-même",
    "Sharing %s failed, because the user %s does not exist" : "Le partage de %s a échoué car l'utilisateur %s n'existe pas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Le partage de %s a échoué car l'utilisateur %s n'est membre d'aucun groupe auquel %s appartient",
    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet objet est déjà partagé avec %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec l'utilisateur %s",
    "Sharing %s failed, because the group %s does not exist" : "Le partage de %s a échoué car le groupe %s n'existe pas",
    "Sharing %s failed, because %s is not a member of the group %s" : "Le partage de %s a échoué car %s n'est pas membre du groupe %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Vous devez fournir un mot de passe pour créer un lien public, seuls les liens protégés sont autorisées.",
    "Sharing %s failed, because sharing with links is not allowed" : "Le partage de %s a échoué car le partage par lien n'est pas permis",
    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
    "Share type %s is not valid for %s" : "Le type de partage %s n'est pas valide pour %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Le réglage des permissions pour %s a échoué car les permissions dépassent celles accordées à %s",
    "Setting permissions for %s failed, because the item was not found" : "Le réglage des permissions pour %s a échoué car l'objet n'a pas été trouvé",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurer la date d'expiration. Un partage ne peut expirer plus de %s après sa création",
    "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurer la date d'expiration : elle est dans le passé.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossible de supprimer la date d'expiration. Les partages doivent avoir une date d'expiration.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Service de partage %s non trouvé",
    "Sharing backend for %s not found" : "Le service de partage pour %s est introuvable",
    "Sharing failed, because the user %s is the original sharer" : "Le partage a échoué car l'utilisateur %s est le propriétaire original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Le partage de %s a échoué car les permissions dépassent celles accordées à %s",
    "Sharing %s failed, because resharing is not allowed" : "Le partage de %s a échoué car le repartage n'est pas autorisé",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
    "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
    "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
    "Expiration date is in the past" : "La date d'expiration est dans le passé",
    "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
    "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
    "Login canceled by app" : "L'authentification a été annulé par l'application",
    "User disabled" : "Utilisateur désactivé",
    "Help" : "Aide",
    "Settings" : "Paramètres",
    "Users" : "Utilisateurs",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
    "web services under your control" : "services web sous votre contrôle",
    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
    "Can't read file" : "Impossible de lire le fichier",
    "Application is not enabled" : "L'application n'est pas activée",
    "Authentication error" : "Erreur d'authentification",
    "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
    "Unknown user" : "Utilisateur inconnu",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
    "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
    "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire apps%s ou en désactivant l'appstore dans le fichier de configuration.",
    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Le problème de permissions peut généralement être résolu %sen donnant au serveur web un accès en écriture au répertoire racine%s",
    "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
    "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
    "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
    "PHP module %s not installed." : "Le module PHP %s n’est pas installé.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP \"%s\" n'est pas \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajuster ce paramètre dans php.ini permettra à ownCloud de fonctionner à nouveau",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
    "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
    "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
    "Your Data directory is readable by other users" : "Votre dossier Data est lisible par les autres utilisateurs",
    "Your Data directory must be an absolute path" : "Votre dossier Data doit être un chemin absolu",
    "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
    "Your Data directory  is invalid" : "Votre dossier Data n'est pas valide",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Veuillez vérifier que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur \"%s\".",
    "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
    "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
    "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
    "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
    "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s"
},
"nplurals=2; plural=(n > 1);");
